aboutsummaryrefslogtreecommitdiffstats
path: root/os/hal
diff options
context:
space:
mode:
Diffstat (limited to 'os/hal')
-rw-r--r--os/hal/ports/NRF51/NRF51822/gpt_lld.h7
1 files changed, 6 insertions, 1 deletions
diff --git a/os/hal/ports/NRF51/NRF51822/gpt_lld.h b/os/hal/ports/NRF51/NRF51822/gpt_lld.h
index d707cda..0e3b544 100644
--- a/os/hal/ports/NRF51/NRF51822/gpt_lld.h
+++ b/os/hal/ports/NRF51/NRF51822/gpt_lld.h
@@ -94,7 +94,12 @@
#if !NRF51_GPT_USE_TIMER0 && !NRF51_GPT_USE_TIMER1 && \
!NRF51_GPT_USE_TIMER2
-#error "GPT driver activated but no TIM peripheral assigned"
+#error "GPT driver activated but no TIMER peripheral assigned"
+#endif
+
+#if (NRF51_GPT_USE_TIMER0 == TRUE) && \
+ (NRF51_SYSTEM_TICKS == NRF51_SYSTEM_TICKS_AS_TIMER)
+#error "GPT driver can't use TIMER0 as currently used by ST driver"
#endif
#if 0